#ifndef ROOT_RootBox
#define ROOT_RootBox

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// RootBox                                                             //
//                                                                      //
// Description of the event and track parameters                        //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#include "TClonesArray.h"
#include "TRefArray.h"
#include "TVector3.h"

const Int_t N=20;

class Traj : public TObject {
public:
   Float_t      fX;           //X of hit
   Float_t      fY;           //Y of hit
   Float_t      fZ;           //Z of hit

public:
    Traj() { }
    virtual ~Traj() { }
   ClassDef(Traj,1)  //A traj hit
};

//______________________________________________________________________
class RootBox : public TObject {
private:
    Int_t        fRun;
    Int_t        fEvent;
    Int_t        fTrackID;
    Int_t        fParentID;
    Int_t        fTrackStatus;
    Int_t        fPDGEncoding;
    Int_t        fTrajPoints;
    Int_t        fNtraj[N];  
    Double_t     fSourcePDGCharge;
    Double_t     fEnergy;
    Double_t     fLength;
    Double_t     fTime;
    TVector3     fMomentum;
    TVector3     fSourcePosition;
    TVector3     fVertexPosition;
    Char_t       CreatorProc[40];
    TClonesArray  *fTraj[N];
public:
    RootBox();
    ~RootBox();
    void SetRunAndEvent(Int_t Run,Int_t Event)
        {
            fRun = Run;
            fEvent=Event;
        }
    void SetTrackID(Int_t TrackID){fTrackID = TrackID;}
    void SetParentID(Int_t ParentID){fParentID = ParentID;}
    void SetTrackStatus(Int_t TrackStatus){fTrackStatus = TrackStatus;}
    void SetPDGEncoding(Int_t PDGEncoding){fPDGEncoding = PDGEncoding;}
    void SetTrajPoints(Int_t TrajPoints){fTrajPoints = TrajPoints;}
    void SetSourcePDGCharge(Double_t SourcePDGCharge)
        {fSourcePDGCharge = SourcePDGCharge;}
    void SetEnergy(Double_t Energy){fEnergy = Energy;}
    void SetVertex(Double_t Length){fLength = Length;}
    void SetGlobalTime(Double_t Time){fTime = Time;}

    void SetCreatorProcess(Char_t *CreatorProcess)
        {
            sprintf(CreatorProc,CreatorProcess);
        }
    
    
    void SetMomentum(TVector3 Momentum){fMomentum = Momentum;}
    void SetSourcePosition(TVector3 SourcePosition){fSourcePosition = SourcePosition ;}
    void SetVertexPosition(TVector3 VertexPosition){fVertexPosition = VertexPosition ;}    

    void Init();
    void SuperPrint();

    Int_t GetTrackID()   const;
    Int_t GetParentID()   const;
    Int_t GetTrackStatus()   const;
    Int_t GetPDGEncoding()  const;
    Int_t GetTrajPoints()  const;
    Int_t GetRun()  const;
    Int_t GetEvent()  const;

    Double_t GetSourcePDGCharge()  const;
    Double_t GetEnergy()  const;
    Double_t GetVertex()  const;
    Double_t GetGlobalTime()  const;

//    Char_t *GetCreatorProcess() const;
    
    TVector3 GetMomentum( )  const;
    TVector3 GetSourcePosition( )  const;
    TVector3 GetVertexPosition( )  const;
    void Build();
    void Clear(Option_t *option ="");
    Traj *AddTraj(Int_t trajID);
    
    ClassDef(RootBox,1)  //Event structure
};

#endif
